@@ -64,26 +64,38 @@ def update_json(data, json_file):
     json_file.close()
 
 
-def fill_json_data():
+def fill_json_new_data():
     os.chdir(GIT_DIR)
     json_obj, json_file = open_json(GIT_JSON_NAME)
     dir_list = os.listdir(REPO_DIR)
     os.chdir(REPO_DIR)
     for file in dir_list:
+        found = False
         if os.path.isdir(file):
             continue
+        for command_files in json_obj.values():
+            if file in command_files:
+                found = True
+                break
+        if found:
+            continue
         file_hash = hash_file(file)
         json_obj[States.NEW].update({file: file_hash})
     update_json(json_obj, json_file)
 
 
+def check_if_file_exists(file_name):
+    if file_name not in os.listdir(os.curdir):
+        print("Error, no JSON FILE FOUND")
+        return False
+    return True
+
+
 def update_modified_status():
     os.chdir(GIT_DIR)
-    if GIT_JSON_NAME in os.listdir(os.curdir):
-        json_obj, json_file = open_json(GIT_JSON_NAME)
-    else:
-        print("Error, no JSON FILE FOUND")
+    if not check_if_file_exists(GIT_JSON_NAME):
         return
+    json_obj, json_file = open_json(GIT_JSON_NAME)
     dir_list = os.listdir(REPO_DIR)
     os.chdir(REPO_DIR)
     file_place = ''
@@ -106,25 +118,22 @@ def update_modified_status():
 
 def display_file_statuses():
     os.chdir(GIT_DIR)
-    if GIT_JSON_NAME in os.listdir(os.curdir):
-        json_obj, json_file = open_json(GIT_JSON_NAME)
-    else:
-        print("Error, no JSON FILE FOUND")
+    if not check_if_file_exists(GIT_JSON_NAME):
         return
+    json_obj, json_file = open_json(GIT_JSON_NAME)
     if States.COMMITED in json_obj:
         del json_obj[States.COMMITED]
     for state, files in json_obj.items():
         for file_name in files.keys():
             print(f"{file_name} ({state} file)")
+    json_file.close()
 
 
 def commit_files():
     os.chdir(GIT_DIR)
-    if GIT_JSON_NAME in os.listdir(os.curdir):
-        json_obj, json_file = open_json(GIT_JSON_NAME)
-    else:
-        print("Error, no JSON FILE FOUND")
+    if not check_if_file_exists(GIT_JSON_NAME):
         return
+    json_obj, json_file = open_json(GIT_JSON_NAME)
     state = States.STAGED
     files = json_obj.get(state)
     files = {k: v for k, v in files.items()}
@@ -136,11 +145,9 @@ def commit_files():
 
 def add_files(arg):
     os.chdir(GIT_DIR)
-    if GIT_JSON_NAME in os.listdir(os.curdir):
-        json_obj, json_file = open_json(GIT_JSON_NAME)
-    else:
-        print("Error, no JSON FILE FOUND")
+    if not check_if_file_exists(GIT_JSON_NAME):
         return
+    json_obj, json_file = open_json(GIT_JSON_NAME)
     if arg == "*":
         states = [States.NEW, States.MODIFIED]
         for state in states:
@@ -163,10 +170,12 @@ def add_files(arg):
 
 
 def add(arg):
+    fill_json_new_data()
     add_files(arg)
 
 
 def status():
+    fill_json_new_data()
     update_modified_status()
     display_file_statuses()
 
@@ -177,7 +186,7 @@ def init():
         return
     init_repository()
     init_json()
-    fill_json_data()
+    fill_json_new_data()
 
 
 def commit():
